"""
Merge criteria used by FeatureDB merge() and merge_all()
"""
from gffutils import Feature


def seqid(acc: Feature, cur: Feature, components: [Feature]):
    return cur.seqid == acc.seqid


def strand(acc: Feature, cur: Feature, components: [Feature]):
    return acc.strand == cur.strand


def feature_type(acc: Feature, cur: Feature, components: [Feature]):
    return acc.featuretype == cur.featuretype


def exact_coordinates_only(acc: Feature, cur: Feature, components: [Feature]):
    return cur.start == acc.start and cur.stop == acc.end


def overlap_end_inclusive(acc: Feature, cur: Feature, components: [Feature]):
    return acc.start <= cur.start <= acc.end + 1


def overlap_start_inclusive(acc: Feature, cur: Feature, components: [Feature]):
    return acc.start <= cur.end + 1 <= acc.end + 1


def overlap_any_inclusive(acc: Feature, cur: Feature, components: [Feature]):
    return acc.start <= cur.start <= acc.end + 1 or acc.start <= cur.end + 1 <= acc.end + 1


#!/usr/bin/env python
import sys

from . import get_args, load_data, merge_all

def main():
    paths, merge_strategy, merge_order, *args = get_args(sys.argv[1:])

    try:
        db = load_data(paths, merge_strategy)
    except ValueError as e:
        # Catch empty data, exit normally
        print(e, file=sys.stderr)
        exit(0)

    merge_all(db, merge_order, *args)

    # Output header
    print("##gff-version 3")

    for feature in db.all_features(order_by=merge_order):
        # Set source
        if ',' in feature.source:
            feature.attributes["sources"] = feature.source.split(',')
            feature.source = "feature_merge"

        print(feature)

if __name__ == "__main__":
    main()

